@@ -2,10 +2,7 @@
 
 use Mail::Cclient;
 
-my $smtp = Mail::Cclient::SMTP->new(
-	hostlist => ["smtp1.perl.org","smtp2.perl.org"],
-	port     => 25
-);
+my $smtp = Mail::Cclient::SMTP->new(["smtp1.perl.org","smtp2.perl.org"]);
 
 $smtp->mail(
 	transaction => "mail",
